@@ -5,7 +5,7 @@ Weasel::Element - The base HTML/Widget element class
 
 =head1 VERSION
 
-0.02
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -22,11 +22,11 @@ attributes and the tag name, etc.
 
 =head1 DEPENDENCIES
 
-This module wraps L<Selenium::Remote::Driver>, version 2.
+
 
 =cut
 
-package Weasel::Element;
+package Weasel::Element 0.32;
 
 use strict;
 use warnings;
@@ -120,6 +120,11 @@ Note: Some browsers apply default values to attributes which are not
   the existence of attributes in the original page and this function
   returning C<undef>.
 
+Note: Those users familiar with Selenium might be looking for a method
+  called C<is_selected> or C<set_selected>. Weasel doesn't have that
+  short-hand. Please use C<get_attribute>/C<set_attribute> with an
+  attribute name of C<selected> instead.
+
 =cut
 
 sub get_attribute {
@@ -128,6 +133,23 @@ sub get_attribute {
     return $self->session->get_attribute($self, $attribute);
 }
 
+=item set_attribute($attribute, $value)
+
+Sets the value of the element's attribute named in C<$attribute>.
+
+Note: Those users familiar with Selenium might be looking for a method
+  called C<is_selected> or C<set_selected>. Weasel doesn't have that
+  short-hand. Please use C<get_attribute>/C<set_attribute> with an
+  attribute name of C<selected> instead.
+
+=cut
+
+sub set_attribute {
+    my ($self, $attribute, $value) = @_;
+
+    return $self->session->set_attribute($self, $attribute, $value);
+}
+
 =item get_text()
 
 Returns the element's 'innerHTML'.
@@ -237,7 +259,7 @@ L<perl-weasel@googlegroups.com|mailto:perl-weasel@googlegroups.com>.
 
 =head1 LICENSE AND COPYRIGHT
 
- (C) 2016-2019  Erik Huelsmann
+ (C) 2016-2023  Erik Huelsmann
 
 Licensed under the same terms as Perl.
 
@@ -247,4 +269,3 @@ Licensed under the same terms as Perl.
 __PACKAGE__->meta->make_immutable;
 
 1;
-
