@@ -5,7 +5,7 @@ Weasel::Widgets::HTML::Input - Parent of the INPUT, OPTION, TEXTAREA and BUTTON
 
 =head1 VERSION
 
-0.28
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -19,7 +19,7 @@ Weasel::Widgets::HTML::Input - Parent of the INPUT, OPTION, TEXTAREA and BUTTON
 
 =cut
 
-package Weasel::Widgets::HTML::Input;
+package Weasel::Widgets::HTML::Input 0.32;
 
 
 use strict;
@@ -122,7 +122,7 @@ L<perl-weasel@googlegroups.com|mailto:perl-weasel@googlegroups.com>.
 
 =head1 LICENSE AND COPYRIGHT
 
- (C) 2016-2019  Erik Huelsmann
+ (C) 2016-2023  Erik Huelsmann
 
 Licensed under the same terms as Perl.
 
